function [warned C F] = checkTooLargeRecal(degChange, j, warned, eyeData, nROI, cfg, F, C, i, smallROI)


if degChange(j) >= 1.5
    if warned == 0
        warned = 1;

        fprintf('\n\nWARNING: large changes made to data (shift of %1.2f). Use with CAUTION.\nMight indicate people often don''t look at your\ndefined ROIs, or else might indicate you had high calibration error\n', ...
                    degChange(j));
    end


    for n = 1:size(eyeData)
        if isfield(eyeData(n), 'rightErrMax') && ~isempty(eyeData(n).rightErrMax)
            errmax = eyeData(n).rightErrMax;
            break;
        end
        if ~exist('errmax', 'var')
            errmax = -1;
        end
    end

    fprintf('\nEyelink-recorded max calibration error (deg): %1.2f\n', errmax);

    %plot it out
    subplot(1,2,1);
    scatter(Fa(1,:), Fa(2,:), 'r');
    hold on;
    for r = 1:nROI
        rectangle('Position', [cfg.ROI.x1(r) cfg.ROI.y1(r) ...
            cfg.ROI.x2(r)-cfg.ROI.x1(r) cfg.ROI.y2(r)-cfg.ROI.y1(r)]);
    end

    if exist('smallROI','var')
        for r = 1:size(smallROI,1)
            rectangle('Position', [smallROI(r,1) smallROI(r,2) smallROI(r,3)-smallROI(r,1) ...
                        smallROI(r,4)-smallROI(r,2)], 'LineStyle', '--');
        end
    end

    axis([0 cfg.screenwidthpix 0 cfg.screenheightpix]);
    title('ORIGINAL fixations [upside down]');

    subplot(1,2,2);
    scatter(Ca(1,:), Ca(2,:), 'b');
    hold on;
    for r = 1:nROI
        rectangle('Position', [cfg.ROI.x1(r) cfg.ROI.y1(r) ...
            cfg.ROI.x2(r)-cfg.ROI.x1(r) cfg.ROI.y2(r)-cfg.ROI.y1(r)]);
    end

    if exist('smallROI','var')
        for r = 1:size(smallROI,1)
            rectangle('Position', [smallROI(r,1) smallROI(r,2) smallROI(r,3)-smallROI(r,1) ...
                        smallROI(r,4)-smallROI(r,2)], 'LineStyle', '--');
        end
    end

    set(gca,'ydir','reverse');
    axis([0 cfg.screenwidthpix 0 cfg.screenheightpix]);
    title(sprintf('RECALIBRATED fixations, change = %1.2f', degChange(j)));

    %if recalibrating per section
    if cfg.nFixperGroup == -1
        xlabel(sprintf('Trial %i section %i',Ftrial(i), Fsec(i)));
    end

    useC = input('Use this change? (plot may be\nhidden behind this window) 1=yes, 0=no: ');
    if useC == 0
        C{j} = F{j}; %replace with the original fixations
    end

    clf;
end