function cfg = initialise

%% data
%what is the name of the variable that contains the data stored in your
%behavioural .mat file? This will be info like the button responses and
%such, the trial-by-trial data you're collecting.
cfg.dataVarName = 'data.trial';



%% section markers


%names of start and end of the trial. recordpos specifies the column
%number where the recordname will be found. recordposval returns a value from
%this same row in that column. If we don't need to return any info from
%that row, set the values to -1. Record info should specify the start and
%the end of the trial.
cfg.ELidentifiers.recordname = {'BOX', 'ENDTRIAL'};
cfg.ELidentifiers.recordpos = [4 3];
cfg.ELidentifiers.recordposval = [8 2];

%as above, for sections
cfg.ELidentifiers.secname = {'STARTMOVIE', 'RATING', 'RESPONSE', 'CONFIDENCE', 'SCALE'};
cfg.ELidentifiers.secpos = [5 5 4 5 5];
cfg.ELidentifiers.secposval = [8 7 7 6 7];


%decision time info. Leave blank and set pos vals to -1 if no RT vals in
%the eye data file. Same for response (resp) values.
cfg.ELidentifiers.RTname = '';
cfg.ELidentifiers.RTpos = [];
cfg.ELidentifiers.RTposval = [];
cfg.ELidentifiers.respname = '';
cfg.ELidentifiers.resppos = [];
cfg.ELidentifiers.respposval = [];

%other info that you might want to grab from the .asc file
cfg.ELidentifiers.trialInfoname = {''};
cfg.ELidentifiers.trialInfopos = [];
cfg.ELidentifiers.trialInfoposval = [];
cfg.ELidentifiers.trialInfoBefore = []; %1=before trial info, 0=after trial info


%if there are practice trials, 
cfg.pracTrials = 1; %are there practice trials? 1=yes

%if so, identify where the experimental trials start
cfg.ELidentifiers.startexptname = 'EXPERIMENTAL';
cfg.ELidentifiers.startexptpos = 3;
cfg.ELidentifiers.startexptposval = -1;


%% fixation definition


%use first fixation from the trial? 1=yes. Often removed because a fixation
%cross or some other stimulus on the preceding page defines the location of
%the first fixation
cfg.firstfix = 0;

%which sections are the ones we want to remove first fixation from? 1st
%section is trial onset, last section is the one just before the end of the
%trial. Set to blank ([]) or -1 if irrelevant. Has no effect if
%cfg.firstfix == 1
cfg.firstfixsec = [1:6];

cfg.minFixDur = 100; %minimum duration for a fixation to be counted as a fixation, in msec

%what sections start with a fixation cross? section #1 begins at trial
%onset. Assumes fixation cross is in the centre of the screen. Blank if
%none
cfg.crossStartSections = [2 4 6];

%% Specify ROIs


%if you specify ROIs, it assumes this will be the same for every trial and
%for every file you select when you run the ELextract script. Currently
%unable to handle files with varying ROIs between trials. If that is how
%your data looks, you should set all these variables to be blank (either {}
%or []). This way it will just output the (x,y) coordinates without
%attempting to locate any ROIs

cfg.ROI.name = {'LEFT','TOP','RIGHT'};
%ROOM C:
% cfg.ROI.x1 = [190 540 890];
% cfg.ROI.y1 = [670 154 670];
% 
% cfg.ROI.x2 = [390 740 1090];
% cfg.ROI.y2 = [770 254 770];

%ROOM B:
cfg.ROI.x1 = [62 412 762];
cfg.ROI.y1 = [542 26 542];

cfg.ROI.x2 = [262 612 962];
cfg.ROI.y2 = [642 126 642];



%% recalibration

%If you want to adjust the ROIs based on the eye tracker calibration error,
%you will need to set these variables. Otherwise, set them to 0.
%
%If using optimisation, be sure to read Vadillo et al (2015)'s paper to
%make sure your data do not violate any of the assumptions. If they do,
%then you'll end up with nonsense data...! Assumes people will actually
%look at the ROIs. If they don't (e.g. Reingold, Pomplun, Charness et al,
%2001), then you might find this distorts your data
%
% ROOM C: 1280 x 1024
% cfg.screenwidthpix = 1280; %screen width in pixels
% cfg.screenheightpix = 1024;
% cfg.viewDistcm = 60; %participant distance from screen, in cm
% cfg.stimWidth = 200; %pixel size of stimulus, if known. set to -1 otherwise
% cfg.scrWidthcm = 34; %width of screen in cm (not including border of screen)
% cfg.scrHeightcm = 27.4;

%ROOM B: 1024 x 768
cfg.screenwidthpix = 1024; %screen width in pixels
cfg.screenheightpix = 768;
cfg.viewDistcm = 60; %participant distance from screen, in cm
cfg.stimWidth = 200; %pixel size of stimulus, if known. set to -1 otherwise
cfg.scrWidthcm = 36.6; %width of screen in cm (not including border of screen)
cfg.scrHeightcm = 27.6;


%adjust ROIs to accomodate tracking error? 1=manual, 2=optimisation, 3=both
cfg.adjustROI = 3; 
cfg.recalSections = 4; %remember that these sections must have same ROIs on screen

%0=not plot; 1=plot all, 2=plot overcalibrated
cfg.plotRecal = 1; %plots the recalibration, if adjustROI == 2 and ROIs specified.
cfg.checkCal = 1; %manually [A] accept or [R] reject each recalibration? 1=yes

cfg.showArrows = 1; %show arrows indicating where points have moved to? 1=yes, 0=no

%% update command window


cfg.idxDisp = -1; %display the "idx"th line being processed to the command window (non-essential)
cfg.trialDisp = 1; %display the nth trial being processed to the command window (non-essential)


%% trial duplicates

%You might have set up your study so that if participants respond
%incorrectly they have to run through the trial again. As a result, you
%will have duplicate trials in the eye data file that should be ignored. If
%so, set this variable to 1, otherwise 0
cfg.trialDuplicates = 0;


%% saving data

cfg.writeraw = 1; %write the raw fixation details to a .csv file? 1=yes
cfg.movefile = 1; %move data files into a subfolder? 1=yes


%% misc settings

%other settings that you shouldn't need to change
cfg=miscSettings(cfg);


%%









%% --------------------------------------------------

%% OTHER SETTINGS, HOPEFULLY YOU WONT NEED TO DEAL WITH THESE


    function cfg=miscSettings(cfg)

        cfg.readall = 1; 
        cfg.readmat = 1; 

        cfg.debugTrial = -1;
        cfg.debugIdx = -1;

        cfg.writesumfile = 0; %write summary data to .csv file? 1=yes
        
        cfg.nFixperGroup = -1; %no of fixations to bound together when running eyeCorrect optimisation. -1 does it by-section
        
        cfg.splitROIs = 1; %if set to 1, splits up the ROIs into smaller boxes to improve recalibration fit. Only applies if cfg.adjustROI == 1
        cfg.splitDeg = 0.7; %degrees to split ROIs into. Increase value to increase recalibration speed, decrease to improve accuracy
        cfg.showSplit = 1; %show the grid of smaller ROIs in the plot? 1=yes
        cfg.splitColor = 'c'; %colour when plotting the smaller split ROIs
        
        cfg.recalOffscreen = 0; %recalibrate those fixations that were off-screen? 0=no
        cfg.fewfixCutoff = .75; %what proportion of sections that were not recalibrated due to lack of fixations

        if cfg.stimWidth > 0
            if isfield(cfg, 'screenwidthpix') && cfg.screenwidthpix > 0
                cfg.pixperdegW = cfg.screenwidthpix/(visang(cfg.viewDistcm,[],cfg.scrWidthcm));
            end
            if isfield(cfg, 'screenheightpix') && cfg.screenheightpix > 0
                cfg.pixperdegH = cfg.screenheightpix/(visang(cfg.viewDistcm,[],cfg.scrHeightcm));
            end
            
            if cfg.adjustROI == 1 || cfg.adjustROI == 3
                recalDegrees = 0.7;
                cfg.recalSize = [cfg.pixperdegW*recalDegrees cfg.pixperdegH*recalDegrees];
                
                cfg=plotPotentialCal(cfg);
                
            else
                cfg.recalSize = [0 0];
            end
        end
        
        %DO NOT CHANGE THIS
        if cfg.pracTrials == 0
            cfg.ELidentifiers.startexptname = '';
            cfg.ELidentifiers.startexptpos = -1;
            cfg.ELidentifiers.startexptposval = -1;
        end
        
        if exist('datafiles/Processed Mat', 'dir') > 0
            addpath(strcat(cd, '/datafiles/Processed Mat'));
        end

    end

%% 
    function cfg=plotPotentialCal(cfg)
        
        breakpoint = 0;
        while breakpoint ~= 2
            
            clf; figure(1);
            for r = 1:length(cfg.ROI.name)
                rectangle('Position', [cfg.ROI.x1(r)-cfg.recalSize(1) cfg.ROI.y1(r)-cfg.recalSize(2) ...
                    cfg.ROI.x2(r)-cfg.ROI.x1(r)+(cfg.recalSize(1)*2) cfg.ROI.y2(r)-cfg.ROI.y1(r)+(cfg.recalSize(2)*2)]);
            end
            
            for r = 1:length(cfg.ROI.name)
                rectangle('Position', [cfg.ROI.x1(r) cfg.ROI.y1(r) ...
                        cfg.ROI.x2(r)-cfg.ROI.x1(r) cfg.ROI.y2(r)-cfg.ROI.y1(r)], 'LineStyle', '--');
            end

            set(gca,'ydir','reverse');
            axis([0 cfg.screenwidthpix 0 cfg.screenheightpix]);
            title('Solid = New ROI, Dashed = Original');
            
            text(10,30,'E = enter new size (degs)');
            text(10,70,'0 = decrease ROI size');
            text(10,110,'1 = increase ROI size');
            text(10,150,'A = accept');
            
            k=0; %wait for button press, not mouse press
            while k==0
                k=waitforbuttonpress;
            end
            keyPress = get(gcf,'CurrentCharacter');
            disp(keyPress);
            
            
            incr = 0.05; %increment 
            
            if strcmpi(keyPress, 'Q')
                error('Q pressed: quitting...');
            elseif strcmp(keyPress, '0') && cfg.ROI.x1(1)+cfg.recalSize(1)-(cfg.pixperdegW*incr) >= cfg.ROI.x1(1) %dont go smaller than ROI size
                cfg.recalSize = cfg.recalSize - (cfg.pixperdegW*incr);
                fprintf('new size: %1.2f deg\n',cfg.recalSize(1)/cfg.pixperdegW);
            elseif strcmp(keyPress,'1')
                cfg.recalSize = cfg.recalSize + (cfg.pixperdegW*incr);
                fprintf('new size: %1.2f deg\n',cfg.recalSize(1)/cfg.pixperdegW);
            elseif strcmpi(keyPress, 'A') 
                breakpoint = 2;
                fprintf('Accepted: increase ROI by (%1.2f, %1.2f) pix (%1.2f deg)\n',...
                    cfg.recalSize(1), cfg.recalSize(2), cfg.recalSize(1)/cfg.pixperdegW);
                disp('---------------------------------');
                pause(.5);
            elseif strcmpi(keyPress, 'E')
                degSize = [];
                while isempty(degSize)
                    degSize = input('Enter size to increase original ROI, in degrees: ');
                end
                cfg.recalSize(1) = (cfg.pixperdegW*degSize); cfg.recalSize(2) = cfg.pixperdegH*degSize;
                fprintf('new size: %1.2f deg\n',cfg.recalSize(1)/cfg.pixperdegW);
            end
            
            clear changeSize;
            
        end
        
        close all;
        
    end %end function


end

    