function [eyeData fixlong fixlongROI] = recalibrate(fixations, cfg, eyeData, e)


    
    %% checks for appropriateness of this algorithm
    
    if isempty(fixations)
        fprintf('\nSKIPPING: No fixations in data file:\n%s\n\n', cfg.flname)
        fixlong = [];
        fixlongROI = '';
        disp('---------------------------------');
        return; %step out of this function
        
    elseif size(fixations,1) < 5
        fprintf('\nWARNING: Few fixations available for correction;\nresults may not improve\n');
    end
    
    fprintf('\nRecalibrating...\nPlease cite Vadillo, Street, Beesley & Shanks (2015, BRM)\n');
    
    %% get stim coordinates
    
    
    for i = 1:length(cfg.ROI.name)

        %find centre of stim
        Cx = cfg.ROI.x1(i) + (cfg.ROI.x2(i) - cfg.ROI.x1(i))/2;
        Cy = cfg.ROI.y1(i) + (cfg.ROI.y2(i) - cfg.ROI.y1(i))/2;

        
        if ~exist('stimCoords','var')
            stimCoords = [Cx Cy];
        else
            stimCoords = [stimCoords;Cx Cy];
        end
        
        if cfg.splitROIs ==1 
            
            x1 = cfg.ROI.x1(i);
            x2 = cfg.ROI.x2(i);
            y1 = cfg.ROI.y1(i);
            y2 = cfg.ROI.y2(i);
            
            [s b] = splitROI(x1, y1, x2, y2, cfg.pixperdegW, cfg.pixperdegH,...
                        cfg.splitDeg);
            
            if ~exist('stimCoordsSplit','var')
                stimCoordsSplit = s;
                smallROI = b;
            else
                stimCoordsSplit = [stimCoordsSplit;s];
                smallROI = [smallROI;b];
            end
            clear s;
        end

    end
    
    %if there's a fixation cross before this trial, create it as a stimulus
    %on this screen. Assume the fixation cross is central
    if ~isempty(cfg.crossStartSections==1)
        if exist('stimCoordsSplit','var')
            stimCoordsSplit(end+1,:) = [cfg.screenwidthpix/2 cfg.screenheightpix/2];
        end
        stimCoords(end+1,:) = [cfg.screenwidthpix/2 cfg.screenheightpix/2]; 
        cfg.ROI.name{end+1} = 'FixCross';
        
        cfg.ROI.x1(end+1) = (cfg.screenwidthpix/2)-30;
        cfg.ROI.y1(end+1) = (cfg.screenheightpix/2)-30;
        cfg.ROI.x2(end+1) = (cfg.screenwidthpix/2)+30;
        cfg.ROI.y2(end+1) = (cfg.screenheightpix/2)+30;
    end
    
    if exist('stimCoordsSplit','var')
        stimCoordsSplit = stimCoordsSplit';
    end
    stimCoords = stimCoords'; %transpose
    
    
    
    
    %% gather fixations, either by section or by groups of fixations.
    % Functions best if using sections. Not currently set up to work using
    % "by groups of fixations" recalibration.
    
    if cfg.nFixperGroup == -1
        
        nsec = length(cfg.ELidentifiers.secname)+1;
        
        trialCountr=1; secCountr = 1; countr=1;
        
        while 1
            Fidx = and(fixations(:,1)==trialCountr, fixations(:,2)==secCountr);
            if sum(trialCountr > fixations(:,1)) == size(fixations,1) %if we've run through all trials
                break;
            end
            
            F{countr} = fixations(Fidx,4:5)';
            Fondur{countr} = fixations(Fidx,6:7);
            Fsec(countr) = secCountr;
            Ftrial(countr) = trialCountr;
            Froi{countr} = e.fixesROI(Fidx==1);
            if secCountr == nsec
                trialCountr=trialCountr+1;
                secCountr=1;
            else
                secCountr=secCountr+1;
            end
            countr = countr+1;
            clear Fidx;
        end
        
   
    elseif size(fixations,1) > cfg.nFixperGroup %if there are more than X fixations in this data file
%         nFix = floor(size(fixations,1)/cfg.nFixperGroup); %number of sets of 15
        
        %comment out this line if you want to try by-groups fixations
        error('Not currently set up to handle arbitrary groups of fixations');
        remFix = rem(size(fixations,1),cfg.nFixperGroup); %and the remainder
        countr=1;
        
        
        for j = 1:cfg.nFixperGroup:size(fixations,1)
            
            
            if j + cfg.nFixperGroup + remFix >= size(fixations,1)
                F{countr} = fixations(j:end,4:5)';
                Fondur(countr) = -1;
                Fsec(countr) = -1;
                Ftrial(countr) = -1;
                Froi{countr} = '';
            else
                %grab a group of fixations
                F{countr} = fixations(j:j+cfg.nFixperGroup-1,4:5)';
                Fondur(countr) = -1;
                Fsec(countr) = -1;
                Ftrial(countr) = -1;
                Froi{countr} = '';
            end
            countr=countr+1;
        end
    end
    
    
 
    
    %% run recalibration, plot out each correction if requested
    
    nNotCalib = 0; counr=0;
    
    for i = 1:length(F)

        if cfg.plotRecal == 1 && ~isempty(cfg.ROI.name) && any(Fsec(i) == cfg.recalSections) ...
            
        counr=counr+1;
            
            if size(F{i},2) >= 5
            

                Fa = F{i};

                FidxA = (Fa(1,:)<0); FidxB = (Fa(1,:)>cfg.screenwidthpix);
                FidxC = (Fa(2,:)<0); FidxD = (Fa(2,:)>cfg.screenheightpix);


                if cfg.recalOffscreen == 0
                    keepFix = (FidxA + FidxB + FidxC + FidxD == 0); %only those that do not go outside screen
                    Fa = Fa(:,keepFix);
                    F{i} = Fa;
                    Fondur{i} = Fondur{i}(keepFix,:);
                    Froi{i} = Froi{i}(keepFix);
                end

                subplot(1,2,1);
                scatter(Fa(1,:), Fa(2,:), 'r');
                hold on;

                %add the fixation cross to this section?
                if any(Fsec(i) == cfg.crossStartSections)
                    nROI = length(cfg.ROI.name);
                    addfixcross = 1;
                else
                    nROI = length(cfg.ROI.name)-1;
                    addfixcross = 0;
                end

                for r = 1:nROI
                    if addfixcross == 1 && r == nROI
                        rectangle('Position', [cfg.ROI.x1(r) cfg.ROI.y1(r) ...
                             cfg.ROI.x2(r)-cfg.ROI.x1(r) cfg.ROI.y2(r)-cfg.ROI.y1(r)]);
                    else
                        rectangle('Position', [cfg.ROI.x1(r)-cfg.recalSize(1) cfg.ROI.y1(r)-cfg.recalSize(2) ...
                            cfg.ROI.x2(r)-cfg.ROI.x1(r)+(cfg.recalSize(1)*2) cfg.ROI.y2(r)-cfg.ROI.y1(r)+(cfg.recalSize(2)*2)]);

                        if any(cfg.recalSize>0) %also show the original ROI
                            rectangle('Position', [cfg.ROI.x1(r) cfg.ROI.y1(r) ...
                            cfg.ROI.x2(r)-cfg.ROI.x1(r) cfg.ROI.y2(r)-cfg.ROI.y1(r)], ...
                            'LineStyle', '--');
                        end
                    end
                end

                set(gca,'ydir','reverse');
                axis([0 cfg.screenwidthpix 0 cfg.screenheightpix]);
                title('ORIGINAL fixations (dashed = original ROI size)');

                %if recalibrating per section
                if cfg.nFixperGroup == -1
                    xlabel(sprintf('Trial %i section %i',Ftrial(i), Fsec(i)));
                end
            end
        end



        if length(F{i}) >= 5 && any(Fsec(i) == cfg.recalSections)
            
            %this is the function taken from Vadillo, Street, Beesley & Shanks,
            %Behavior Research Methods. Only perform the correction if there
            %are at least 5 fixations to use for correction.
            if exist('stimCoordsSplit','var')
                
                Fa = F{i};
                
                if any(Fsec(i) == cfg.crossStartSections)
                    C{i} = fixationRecalibration(Fa, stimCoordsSplit);
                else
                    C{i} = fixationRecalibration(Fa, stimCoordsSplit(:,1:end-1));
                end
                
            else
                
                
                if any(Fsec(i) == cfg.crossStartSections)    
                    C{i} = fixationRecalibration(Fa, stimCoords);
                else
                    C{i} = fixationRecalibration(Fa, stimCoords(:,1:end-1));
                end
            end
        
            if cfg.plotRecal == 1 && ~isempty(cfg.ROI.name)
                subplot(1,2,2);
                Ca = C{i};
                scatter(Ca(1,:), Ca(2,:), 'b');
                hold on;
                
                if exist('smallROI','var') && cfg.showSplit == 1
                    for r = 1:size(smallROI,1)
                        rectangle('Position', [smallROI(r,1) smallROI(r,2) smallROI(r,3)-smallROI(r,1) ...
                                    smallROI(r,4)-smallROI(r,2)], 'LineStyle', ':', ...
                                    'EdgeColor', cfg.splitColor);
                    end
                end
                 
                
                for r = 1:nROI
                    if addfixcross == 1 && r == nROI
                        rectangle('Position', [cfg.ROI.x1(r) cfg.ROI.y1(r) ...
                             cfg.ROI.x2(r)-cfg.ROI.x1(r) cfg.ROI.y2(r)-cfg.ROI.y1(r)]);
                    else
                        rectangle('Position', [cfg.ROI.x1(r)-cfg.recalSize(1) cfg.ROI.y1(r)-cfg.recalSize(2) ...
                        cfg.ROI.x2(r)-cfg.ROI.x1(r)+(cfg.recalSize(1)*2) ...
                        cfg.ROI.y2(r)-cfg.ROI.y1(r)+(cfg.recalSize(2)*2)]);
                    
                        if any(cfg.recalSize>0) %also show the original ROI
                            rectangle('Position', [cfg.ROI.x1(r) cfg.ROI.y1(r) ...
                            cfg.ROI.x2(r)-cfg.ROI.x1(r) cfg.ROI.y2(r)-cfg.ROI.y1(r)], ...
                            'LineStyle', '--');
                        end
                    
                    end
                end
                
                
                %rescale if none of the fixation points are out of bounds
                if ~(any(Ca(1,:) < 0) || any(Ca(1,:) > cfg.screenwidthpix) || ...
                     any(Ca(2,:) < 0) || any(Ca(2,:) > cfg.screenheightpix))
                 
                         axis([0 cfg.screenwidthpix 0 cfg.screenheightpix]);
                end
                
                set(gca,'ydir','reverse'); %flip figure upside down
                
                
                if cfg.showArrows == 1
                    showCalibArrows(Fa, Ca, cfg);
                end
                
                
                title('RECALIBRATED fixations');
                
                if cfg.checkCal == 1
                    text(20,80,'[R] = reject correction');
                    text(20,40,'[Any key] = accept');
                    
                    k=0; %wait for button press, not mouse press
                    while k==0
                        k=waitforbuttonpress;
                    end
                    keyPress = get(gcf,'CurrentCharacter');
                    if upper(keyPress) == 'R'
                        C{i} = F{i};
                        Croi{i} = Froi{i};
                    else
                        Croi{i} = recalROIs(cfg, Ca);
                    end
                elseif cfg.checkCal == 0
                    Croi{i} = recalROIs(cfg, Ca);
                    pause(2);
                end
                clf;
            end
        else
            C{i} = F{i};
            Croi{i} = Froi{i};
            if length(F{i}) < 5 && any(Fsec(i) == cfg.recalSections)
                nNotCalib = nNotCalib +1;
            end
        end
            
        clf;
        
    end
    
    close; %close figures
    
    if nNotCalib > 0
        fprintf(...
            '\nDidn''t recalibrate %i of %i sections\nbecause fewer than 5 onscreen fixations in section\n',...
            nNotCalib, counr);
        
        if nNotCalib/counr >= cfg.fewfixCutoff
            pause(2);
            fprintf('\n\nWARNING: a large proportion of trials were not recalibrated.\nThis may indicate too few fixations per trials\nto use this automated recalibration procedure\n\n');
            pause(3);
            disp('---------------------------------');
        end
    end
    
    %% check for recalibration size, see if abnormal
    
    warned = 0;
    for j = 1:length(C)
        Ca = C{j};
        Fa = F{j};
        %check the average distance correction. If it's large, produce a
        %warning and don't use the corrected value.
        for k = 1:size(Ca,2)
            dist(k) = sqrt((Ca(1,k) - Fa(1,k))^2 + (Ca(2,k) - Fa(2,k))^2);
            %convert dist (pixels) to degrees of error
            dC(k,:) = [dist(k)/cfg.pixperdegW dist(k)/cfg.pixperdegH];
        end

        if exist('dC','var')
            degChange(j) = mean(dC(:));
        elseif ~exist('degChange', 'var')
            degChange = [];
        else
            degChange(j) = [];
        end
        
        if exist('smallROI','var') && exist('nROI','var') && ~isempty(degChange)
            [warned C F] = checkTooLargeRecal(degChange, j, warned, eyeData, nROI, cfg, F, C, i, smallROI);
        elseif exist('nROI','var') && ~isempty(degChange)
            [warned C F] = checkTooLargeRecal(degChange, j, warned, eyeData, nROI, cfg, F, C, i);
        end
        
        
    end

    close; %close figures
    
    
    %% reassign from C back into eyeData in the appropriate places
    
    %if we've not already checked each calibration
    if cfg.checkCal == 0
        x=sprintf('\nCorrected the data by\nbetween %1.2f to %1.2f degrees.\nUse this? [1=yes]: ',...
                                        min(degChange), max(degChange));
        useChange = input(x);
    elseif max(degChange) > 0
    	fprintf('\nCorrected the data by\nbetween %1.2f to %1.2f degrees.\n', ...
                                        min(degChange), max(degChange));
        useChange = 1;
    else
        fprintf('\No corrections made and/or required\n');
        useChange = 1;
    end
    
    
    if useChange == 1

        ctr=0;
        %save long form of the data
        for k = 1:length(C)
            dat = C{k};
            datOn = Fondur{k};

            
            %[e.trialno e.secno e.fixcount x y]
            if ~exist('fixlong','var') && ~any(size(dat)==0)
                fixlong = [fixations(ctr+1:size(dat,2),1:3) dat' datOn]; %save a copy of the long form data 
            elseif ~any(size(dat)==0)
                fixlong = [fixlong; fixations(ctr+1:ctr+size(dat,2),1:3) dat' datOn]; %save a copy of the long form data
            end
            
            if exist('fixlong','var')
                ctr = size(fixlong,1);
            end
        end

        %reassign back into eyeData
        for i = 1:length(fixlong)
            eyeData(fixlong(i,1)).section(fixlong(i,2)).x(fixlong(i,3)) = fixlong(i,4);
            eyeData(fixlong(i,1)).section(fixlong(i,2)).y(fixlong(i,3)) = fixlong(i,5);
        end
        
        
        ctr=0;
        %save long form of the data
        for k = 1:length(Croi)
            roi = Croi{k};
            
            for j = 1:length(roi)
                fixlongROI{ctr+j} = roi{j};
            end
            
            if exist('fixlongROI', 'var')
                ctr = length(fixlongROI);
            else
                ctr=0;
            end
        end
        
        
        for i = 1:length(fixlongROI)
            eyeData(fixlong(i,1)).section(fixlong(i,2)).ROI = fixlongROI{i};
        end

    else
        fixlong = fixations;
    end
    
    
end