function [filenames pathname nFiles] = selectFiles(filetype, suppress)
%[filenames pathname nFiles] = selectFiles(filetype[, suppress])
%   filenames is a cell of strings. If suppress specified as 1, will not
%   print out the filenames to the command window

if nargin < 2
    suppress = 0;
end

if nargin < 1
    filetype = input('filetype (no dot): ', 's');
end

pathname = 0; c = 0;
while isnumeric(pathname) && c ~= 2
    [filenames, pathname] = uigetfile('MultiSelect', 'on', {['*.' filetype], ...
        ['Data files (.' filetype ')']; '*.*', 'All Files (.*)'}, ...
        ['Select ' filetype ' file(s)']);

    %determine if one item has been selected (in which case, filenames is
    %char), or multiple items have been selected (in which case, filenames is
    %a cell array)
    types = whos('filenames', 'class'); %get info for variable called filenames

    %find out if it's a char or cell
    if strcmp(types.class, 'char') == 1 %if string
        nFiles = 1;
    else
        %otherwise, cell
        nFiles = size(filenames,2);

        if suppress == 0
            %display list that is to be processed
            fprintf('\nFiles to be processed:\n');
            for j = 1:nFiles
                fprintf('%s\n',filenames{j});
            end
        end
    end

    if pathname ~= 0
        addpath(pathname);
    else
        c=c+1; %keep track of number of tries. Only allow two tries, then fail
    end
end

if c == 2
    error('A file must be selected');
end

