function [s b] = splitROI(x1, y1, x2, y2, pixperdegW, pixperdegH, splitDeg)
%take and ROI and split it into smaller regions.
%inputs:
%   - the top-left (x1, y1) and bottom-right (x2, y2) position of the ROI
%   to be split
%   - pixperdegW and H: the number of pixels (Width and Height) per 1
%   degree of visual angle
%   -splitDeg: split up the ROI so that each new smaller ROI has this many
%   degrees of visual angle
%
%outputs:
%   -s: the centre of each of the new smaller ROIs
%   -b: the rectangle (x1, y1, x2, y2) coordinates of each smaller ROI

%split ROIs into 0.5 degree boxes
splitPixX = splitDeg*pixperdegW;
splitPixY = splitDeg*pixperdegH;

xSize = abs(x2-x1);
ySize = abs(y2-y1);


%if able to split the ROI, find the edges of the new smaller boxes
for j = 1:length(xSize)
    if xSize(j)/2 >= splitPixX
        %determine number of boxes and their size
        nX(j) = floor(xSize(j)/splitPixX);
        rX = rem(xSize(j),splitPixX);
        remX(j) = rX/nX(j);
        if nX(j) == 0
            nX(j) = rX;
            remX(j) = rX;
            edgeX{j,1} = x1(j); edgeX{j,2} = x2(j);
        end
        
        %get markers for drawing up box edges
        edgeX{j,1} = x1(j);
        for i = 2:nX(j)+1
            edgeX{j,i} = x1(j)+(splitPixX*(i-1))+(remX(j)*(i-1));
        end    
        edgeX{j,end} = x2(j);
    else
        edgeX{j,1} = x1(j); edgeX{j,2} = x2(j);
    end

    if ySize(j)/2 >= splitPixY
        %determine number of boxes and their size
        nY(j) = floor(ySize(j)/splitPixY);
        rY = rem(ySize(j),splitPixY);
        remY(j) = rY/nY(j);
        if nY(j) == 0
            nY(j) = rY;
            remY(j) = rY;
            edgeY{j,1} = y1(j); edgeY{j,2} = y2(j);
        end
        
        %get markers for drawing up box edges
        edgeY{j,1} = y1(j);
        for i = 2:nY(j)+1
            edgeY{j,i} = y1(j)+(splitPixY*(i-1))+(remY(j)*i-1);
        end
        edgeY{j,end} = y2(j);
    else
        edgeY{j,1} = y1(j); edgeY{j,2} = y2(j);
    end
end


%draw boxes
ctr=1;
for s = 1:size(edgeX,1) %for each large ROI
    
    eX = edgeX(s,:);
    eX = eX(~cellfun('isempty',eX)); %remove empty cells
    eY = edgeY(s,:);
    eY = eY(~cellfun('isempty',eY)); %remove empty cells
    
    for i = 1:length(eY)-1
        for j = 1:length(eX)-1

            b(ctr,:) = [edgeX{s,j} edgeY{s,i} edgeX{s,j+1} edgeY{s,i+1}];
            ctr=ctr+1;
        end
    end
end

%for each box, find centres
for i = 1:size(b,1)
    s(i,1) = b(i,1)+((b(i,3)-b(i,1))/2);
    s(i,2) = b(i,2)+((b(i,4)-b(i,2))/2);
end